@@ -1,10 +1,5 @@
 #!/usr/bin/env bash
 
-make_goroot_read_only()
-{
-    find $PREFIX/go -type d -exec chmod 555 {} \;
-}
-
 build_linux()
 {
     make hyperkube
@@ -25,8 +20,7 @@ build_osx()
     mv _output/bin/kubectl $PREFIX/bin
 }
 
-make_goroot_read_only
-
+mkdir -p $PREFIX/bin
 case $(uname -s) in
     "Linux")
         build_linux
